@@ -1,4 +1,4 @@
-/* $Id: rapi.h 3116 2007-12-23 14:01:55Z gdiepen $ */
+/* $Id: rapi.h 3791 2009-07-12 17:27:04Z mark_ellis $ */
 #ifndef __rapi_h__
 #define __rapi_h__
 
@@ -80,11 +80,23 @@ void rapi_connection_select(RapiConnection* connection);
 /** Destroy connection object - use this after CeRapiUninit() */
 void rapi_connection_destroy(RapiConnection* connection);
 
+/** get information about the connected device */
+const char *rapi_connection_get_name(RapiConnection* connection);
+bool rapi_connection_get_os_version(RapiConnection* connection, int *os_major, int *os_minor);
+int rapi_connection_get_build_number(RapiConnection* connection);
+int rapi_connection_get_processor_type(RapiConnection* connection);
+const char *rapi_connection_get_os_name(RapiConnection* connection);
+const char *rapi_connection_get_model(RapiConnection* connection);
+const char *rapi_connection_get_device_ip(RapiConnection* connection);
+const char *rapi_connection_get_local_ip(RapiConnection* connection);
+/** this should not be used directly for data, only for monitoring purposes */
+int rapi_connection_get_fd(RapiConnection* connection);
+
 /*
  * Main RAPI functions
  */
 
-#define CERAPI_E_ALREADYINITIALIZED  0x8004101
+#define CERAPI_E_ALREADYINITIALIZED  0x80041001
 
 #ifndef SWIG
 
@@ -152,6 +164,7 @@ DWORD CeRapiGetLastError();
 #define FILE_CURRENT    1
 #define FILE_END        2
 
+#define INVALID_FILE_SIZE 0xFFFFFFFF
 
 #ifndef SWIG
 
@@ -240,6 +253,7 @@ BOOL CeSetFileTime(
 
 #ifndef SWIG
 
+/* deprecated, use rapi_copy_file() */
 BOOL CeCopyFileA(
 		LPCSTR lpExistingFileName,
 		LPCSTR lpNewFileName,
@@ -314,6 +328,11 @@ BOOL CeSHCreateShortcut(
 
 BOOL CeSyncTimeToPc();
 
+bool rapi_copy_file(
+		const char *source_file_name,
+		const char *dest_file_name,
+		bool fail_if_exists);
+
 #endif /* SWIG */
 
 
@@ -891,6 +910,7 @@ HRESULT CeRapiInvoke(
 		IRAPIStream **ppIRAPIStream,
 		DWORD dwReserved);
 
+/* deprecated, use rapi_invoke() */
 HRESULT CeRapiInvokeA(
 		LPCSTR pDllPath,
 		LPCSTR pFunctionName,
@@ -901,6 +921,16 @@ HRESULT CeRapiInvokeA(
 		IRAPIStream **ppIRAPIStream,
 		DWORD dwReserved);
 
+HRESULT rapi_invoke( /*{{{*/
+		const char *dll_path,
+		const char *function_name,
+		DWORD cbInput,
+		const BYTE *pInput,
+		DWORD *pcbOutput,
+		BYTE **ppOutput,
+		IRAPIStream **ppIRAPIStream,
+		DWORD dwReserved);
+
 #endif /* SWIG */
 
 #ifdef __cplusplus
