@@ -1,4 +1,4 @@
-/* $Id: file_management2.c 3453 2008-05-09 09:57:47Z mark_ellis $ */
+/* $Id: file_management2.c 3790 2009-07-12 16:24:19Z mark_ellis $ */
 #include "rapi_internal.h"
 #include "rapi2_api.h"
 #include "rapi_buffer.h"
@@ -268,14 +268,13 @@ BOOL _CeRemoveDirectory2(
     return return_value;
 }
 
-#define BAD_FILE_SIZE 0xffffffff
 
 DWORD _CeGetFileSize2(
         HANDLE hFile,
         LPDWORD lpFileSizeHigh)
 {
     RapiContext* context = rapi_context_current();
-    DWORD size = BAD_FILE_SIZE;
+    DWORD size = INVALID_FILE_SIZE;
 
     rapi_context_begin_command(context, 0x2e);
     rapi_buffer_write_uint32(context->send_buffer, (uint32_t)hFile);
@@ -283,17 +282,17 @@ DWORD _CeGetFileSize2(
     lpFileSizeHigh, sizeof(*lpFileSizeHigh));
 
     if ( !rapi2_context_call(context) )
-        return BAD_FILE_SIZE;
+        return INVALID_FILE_SIZE;
 
     if ( !rapi_buffer_read_uint32(context->recv_buffer, &context->last_error) )
-        return BAD_FILE_SIZE;
+        return INVALID_FILE_SIZE;
     synce_trace("last_error = %i", context->last_error);
 
     if ( !rapi_buffer_read_uint32(context->recv_buffer, &size) )
-        return BAD_FILE_SIZE;
+        return INVALID_FILE_SIZE;
 
     if ( !rapi_buffer_read_optional_uint32(context->recv_buffer, lpFileSizeHigh) )
-        return BAD_FILE_SIZE;
+        return INVALID_FILE_SIZE;
 
     return size;
 }
@@ -301,8 +300,6 @@ DWORD _CeGetFileSize2(
 
 /**
  * This function copies an existing file to a new file.
- *
- * Unicode version.
  */
 BOOL _CeCopyFile2(
         LPCWSTR lpExistingFileName,
@@ -326,38 +323,6 @@ BOOL _CeCopyFile2(
     return return_value;
 }
 
-/**
- * This function copies an existing file to a new file.
- *
- * Ascii version.
- */
-BOOL _CeCopyFileA2(
-        LPCSTR lpExistingFileName,
-        LPCSTR lpNewFileName,
-        BOOL bFailIfExists)
-{
-    BOOL return_value = 0;
-    LPWSTR lpExistingFileNameW = NULL;
-    LPWSTR lpNewFileNameW = NULL;
-
-    lpExistingFileNameW = wstr_from_current(lpExistingFileName);
-    lpNewFileNameW      = wstr_from_current(lpNewFileName);
-
-    if (lpExistingFileName && !lpExistingFileNameW)
-        goto fail;
-
-    if (lpNewFileName && !lpNewFileNameW)
-        goto fail;
-
-    return_value = CeCopyFile(lpExistingFileNameW, lpNewFileNameW, bFailIfExists);
-
-fail:
-    wstr_free_string(lpExistingFileNameW);
-    wstr_free_string(lpNewFileNameW);
-
-    return return_value;
-}
-
 BOOL _CeMoveFile2(
         LPCWSTR lpExistingFileName,
         LPCWSTR lpNewFileName)
