@@ -1,4 +1,4 @@
-/* $Id: rapi_indirection.h 3116 2007-12-23 14:01:55Z gdiepen $ */
+/* $Id: rapi_indirection.h 3790 2009-07-12 16:24:19Z mark_ellis $ */
 #undef __STRICT_ANSI__
 #define _GNU_SOURCE
 #include "rapi.h"
@@ -64,11 +64,6 @@ struct rapi_ops_s
 
 #ifndef SWIG
 
-    BOOL ( *CeCopyFileA ) (
-        LPCSTR lpExistingFileName,
-        LPCSTR lpNewFileName,
-        BOOL bFailIfExists );
-
     BOOL ( *CeCopyFile ) (
             LPCWSTR lpExistingFileName,
     LPCWSTR lpNewFileName,
@@ -359,23 +354,6 @@ struct rapi_ops_s
 
 #ifndef SWIG
 
-    ULONG ( *IRAPIStream_Release ) ( IRAPIStream* stream );
-
-    HRESULT ( *IRAPIStream_Read ) (
-            IRAPIStream* stream,
-    void *pv,
-    ULONG cb,
-    ULONG *pcbRead );
-
-    HRESULT ( *IRAPIStream_Write ) (
-            IRAPIStream* stream,
-    void const *pv,
-    ULONG cb,
-    ULONG *pcbWritten );
-    /*
-    int (*IRAPIStream_GetRawSocket)(IRAPIStream* stream);
-    */
-
     HRESULT ( *CeRapiInvoke ) (
             LPCWSTR pDllPath,
     LPCWSTR pFunctionName,
@@ -386,15 +364,5 @@ struct rapi_ops_s
     IRAPIStream **ppIRAPIStream,
     DWORD dwReserved );
 
-    HRESULT ( *CeRapiInvokeA ) (
-            LPCSTR pDllPath,
-    LPCSTR pFunctionName,
-    DWORD cbInput,
-    const BYTE *pInput,
-    DWORD *pcbOutput,
-    BYTE **ppOutput,
-    IRAPIStream **ppIRAPIStream,
-    DWORD dwReserved );
-
 #endif /* SWIG */
 };
